//-------------------------------------------------------------------------------------------------+
// * @file  MessageReceiver.cpp
// * @brief receive message (string data) and display it on console.
//-------------------------------------------------------------------------------------------------+

#include "MessageReceiver.h"
#include <iostream>

using namespace std;


//-------------------------------------------------------------------------------------------------+
// Module specification
//-------------------------------------------------------------------------------------------------+
static const char* messagereceiver_spec[] =
  {
    "implementation_id", "MessageReceiver",
    "type_name",         "MessageReceiver",
    "description",       "receive message (string data) and display on console.",
    "version",           "1.0.0",
    "vendor",            "aisl.cs.tut.ac.jp",
    "category",          "Viewe",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "0",
    "language",          "C++",
    "lang_type",         "compile",
    ""
  };


//-------------------------------------------------------------------------------------------------+
// * @brief constructor
// * @param manager Maneger Object
//-------------------------------------------------------------------------------------------------+
MessageReceiver::MessageReceiver(RTC::Manager* manager)
  : RTC::DataFlowComponentBase(manager),
    m_messageIn("message", m_message)
{

	cerr << "------------------------------------------------------------+\n"
		 << " MessageReceiver Component (Ver. 25th November 2011)\n"
		 << "------------------------------------------------------------+\n\n";
}


//-------------------------------------------------------------------------------------------------+
// * @brief destructor
//-------------------------------------------------------------------------------------------------+
MessageReceiver::~MessageReceiver(){
}


//-------------------------------------------------------------------------------------------------+
// 
// Registration: InPort
//-------------------------------------------------------------------------------------------------+
RTC::ReturnCode_t MessageReceiver::onInitialize(){

	// Set InPort buffers
	addInPort("message", m_messageIn);

	return RTC::RTC_OK;
}


//-------------------------------------------------------------------------------------------------+
// s郁C̏
//-------------------------------------------------------------------------------------------------+
RTC::ReturnCode_t MessageReceiver::onExecute(RTC::UniqueId ec_id){

	if( !m_messageIn.isNew() ) return RTC::RTC_OK;

	while( !m_messageIn.isEmpty() ){

		m_messageIn.read();

		cerr << m_message.data << endl;
//		cerr << m_message.data << " \t(time:" << m_message.tm.sec << ")" << endl;
	}

	return RTC::RTC_OK;
}



//-------------------------------------------------------------------------------------------------+
extern "C"
{
 
  void MessageReceiverInit(RTC::Manager* manager)
  {
    coil::Properties profile(messagereceiver_spec);
    manager->registerFactory(profile,
                             RTC::Create<MessageReceiver>,
                             RTC::Delete<MessageReceiver>);
  }
};
